## 市场参考数据

正如开篇所讲，公司行为、市场行为等市场参考数据是Pro未来可以有极大发挥的地方。我们将努力为大家提供尽可能多的数据内容，因为这一部分的很多数据可以为大家提供具有更有发掘价值的信息。

这一部分数据将采用迭代的方式，有新的就上新，没有新的就继续规划和发掘。很欢迎大家在Tushare社区里积极建言，提交需求，尤其是有意思的数据，我们分析确认后将纳入整体规划。对了，提供需求和建议，我们会有积分赠送哦。

从已经上线的数据来罗列，主要有以下：

- 沪深港通资金流向
- 沪深股通十大成交股
- 港股通十大成交股
- 融资融券交易汇总
- 融资融券交易明细